<?xml version="1.0" encoding="ISO-8859-1" ?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" version="1.0">
  
  <xsl:import href="biblio.xsl"/>
  <xsl:import href="title.xsl"/>
  <xsl:import href="styles/bibtex.xsl"/>
  
  <xsl:param name="lang"> en</xsl:param>
  
  <xsl:output method="html" version="4.0" encoding="ISO-8859-1" indent="yes"/>
  <xsl:strip-space elements="*"/>
  <xsl:variable name="title" select="$display/query/bartitle/text[@lang=$lang]"/>
  <xsl:template match="/biblio">
    <html>
      <head> 
	<link rel="stylesheet" type="text/css" href="../css/style.css"/>
	<title> 
	  <xsl:value-of select="$title"/>
	</title>
      </head>
      <body>
	<xsl:variable name="mess_and" select="$display/query/and/text[@lang=$lang]"/>
	<xsl:variable name="mess_intro" select="$display/query/intro/text[@lang=$lang]"/>
	<xsl:variable name="mess_title" select="$display/query/title/text[@lang=$lang]"/>
	<xsl:variable name="mess_year" select="$display/query/year/text[@lang=$lang]"/>
	<xsl:variable name="mess_author" select="$display/query/author/text[@lang=$lang]"/>
	<xsl:variable name="mess_theme" select="$display/query/theme/text[@lang=$lang]"/>

	<xsl:call-template name="create_title">
	  <xsl:with-param name="title" select="$title"/>
	  <xsl:with-param name="file">
	    <xsl:value-of select="concat('search.cgi?mode=plain&amp;lang=xx&amp;subtitle=',$subtitle,'&amp;subauthor=',$subauthor,'&amp;year=',$year,'&amp;theme=',$theme)"/>
	  </xsl:with-param>
	  <xsl:with-param name="class" select="'finaltitle'"/>
	</xsl:call-template>
	<xsl:call-template name="biblio_styles">
	  <xsl:with-param name="link_plain">
	    <xsl:value-of select="concat('search.cgi?mode=plain&amp;lang=',$lang,'&amp;subtitle=',$subtitle,'&amp;subauthor=',$subauthor,'&amp;year=',$year,'&amp;theme=',$theme)"/>
	  </xsl:with-param>
	  <xsl:with-param name="link_author">
	    <xsl:value-of select="concat('search.cgi?mode=authordate&amp;lang=',$lang,'&amp;subtitle=',$subtitle,'&amp;subauthor=',$subauthor,'&amp;year=',$year,'&amp;theme=',$theme)"/>
	  </xsl:with-param>
	  <xsl:with-param name="link_bibtex">
	    <xsl:value-of select="concat('search.cgi?mode=bibtex&amp;lang=',$lang,'&amp;subtitle=',$subtitle,'&amp;subauthor=',$subauthor,'&amp;year=',$year,'&amp;theme=',$theme)"/>
	  </xsl:with-param>
	</xsl:call-template>
	
	<div class="thequery">
	  <xsl:value-of select="$mess_intro"/>
	  <br/>
	  <xsl:if test="$subtitle !=''">
	    <div class="queryitem">
	      <xsl:value-of select="$mess_title"/>
	      <xsl:value-of select="$subtitle"/>
	      <xsl:text>) </xsl:text>
	      <xsl:if test="concat($year,$subauthor,$theme) != ''">
		<xsl:value-of select="$mess_and"/>
	      </xsl:if>
	    </div>
	  </xsl:if>
	  <xsl:if test="$year !=''">
	    <div class="queryitem">
	      <xsl:value-of select="$mess_year"/>
	      <xsl:value-of select="$year"/>
	      <xsl:text>) </xsl:text>
	      <xsl:if test="concat($subauthor,$theme) != ''">
		<xsl:value-of select="$mess_and"/>
	      </xsl:if>
	    </div>
	  </xsl:if>
	  <xsl:if test="$subauthor !=''">
	    <div class="queryitem">
	      <xsl:value-of select="$mess_author"/>
	      <xsl:value-of select="$subauthor"/>
	      <xsl:text>) </xsl:text>
	      <xsl:if test="$theme != ''">
		<xsl:value-of select="$mess_and"/>
	      </xsl:if>
	    </div>
	  </xsl:if>
	  <xsl:if test="$theme !=''">
	    <div class="queryitem">
	      <xsl:value-of select="$mess_theme"/>
	      <xsl:value-of select="$themes//theme[@keyword=$theme]/text[@lang=$lang]"/>
	      <xsl:text> &#187;) </xsl:text>
	    </div>
	  </xsl:if>
	</div>
	<xsl:variable name="keywords">	  
	  <xsl:for-each select="$themes/theme[@keyword=$theme]//@keyword">
	    <xsl:value-of select="."/>
	    <xsl:text> </xsl:text>
	  </xsl:for-each>
	</xsl:variable>
	<xsl:choose>	
	  <xsl:when test="$mode = '' or $mode='plain'">
	    <xsl:apply-templates select="./entry[($subtitle='' or contains(./*/title,$subtitle) or  contains(./*/abstract,$subtitle)) and ($year ='' or $year &lt; ./*/year) and ($subauthor='' or ./*/author[contains(lastname,$subauthor) or contains(firstname,$subauthor)]) and ($theme='' or ./*/theme[contains($keywords,normalize-space(text()))] or ./*/theme[normalize-space(text())=$theme])]">
	      <xsl:sort select="./*/author/lastname"/>
	      <xsl:sort select="./*/year" data-type="number" order="descending"/>
	      <xsl:sort select="./*/editor/lastname"/>
	      <xsl:sort select="./*/publisher"/>
	    </xsl:apply-templates>
	  </xsl:when>
	  <xsl:when test="$mode='authordate'">
	    <xsl:apply-templates select="./entry[($subtitle='' or contains(./*/title,$subtitle) or  contains(./*/abstract,$subtitle)) and ($year ='' or $year &lt; ./*/year) and ($subauthor='' or ./*/author[contains(lastname,$subauthor) or contains(firstname,$subauthor)]) and ($theme='' or ./*/theme[contains($keywords,normalize-space(text()))] or ./*/theme[normalize-space(text())=$theme])]" mode="authordate">
	      <xsl:sort select="./*/author/lastname"/>
	      <xsl:sort select="./*/year" data-type="number" order="descending"/>
	      <xsl:sort select="./*/editor/lastname"/>
	      <xsl:sort select="./*/publisher"/>
	    </xsl:apply-templates>
	  </xsl:when>
	  <xsl:otherwise>
	    <pre>
	      <xsl:apply-templates select="./entry[($subtitle='' or contains(./*/title,$subtitle) or  contains(./*/abstract,$subtitle)) and ($year ='' or $year &lt; ./*/year) and ($subauthor='' or ./*/author[contains(lastname,$subauthor) or contains(firstname,$subauthor)]) and ($theme='' or ./*/theme[contains($keywords,normalize-space(text()))] or ./*/theme[normalize-space(text())=$theme])]" mode="bibtex">
		<xsl:sort select="./*/author/lastname"/>
		<xsl:sort select="./*/year" data-type="number" order="descending"/>
		<xsl:sort select="./*/editor/lastname"/>
		<xsl:sort select="./*/publisher"/>
	      </xsl:apply-templates>
	    </pre>
	  </xsl:otherwise>
	</xsl:choose>
      </body>
    </html>
  </xsl:template>
</xsl:stylesheet>
